smartcard.CardNames.__CardNames__

# ``smartcard`.`CardNames`.`__CardNames__``

class documentation

`class __CardNames__(Synchronization):`

View In Hierarchy

__CardNames__ inner class.

Stores card names and card types into a bsddb hash database.

The `smartcard.CardNames.CardNames` singleton manages the creation of the unique instance of this class.

Method | `__del__` | Undocumented
Method | `__init__` | Undocumented
Method | `add` | Undocumented
Method | `delete` | Undocumented
Method | `dump` | Undocumented
Method | `find` | Undocumented
Instance Variable | `db` | Undocumented

Inherited from `Synchronization`:

Instance Variable | `mutex` | Undocumented

def __del__(self):

Undocumented

def __init__(self):
overrides `smartcard.Synchronization.Synchronization.__init__`

Undocumented

def add(self, cardname, cardtype):

Undocumented

def delete(self, cardname):

Undocumented

def dump(self):

Undocumented

def find(self, atr, reader=None):

Undocumented

db =

Undocumented